Brief :: marketing i sprzedaż | reklama | media | pr |
Keywords: marketing, sprzedaż, reklama, media, pr, kampanie reklamowe, brief, Grzegorz Kiszluk, promocje, reklamy, narzędzia do prowadzenia biznesu

Brief.pl / Inspiracje

Kalendarz Pirelli – zmiana wizerunku marki?

Kilka dni temu media na całym świecie szeroko opisywały temat nowego Kalendarza Pirelli. Niby żadne to wydarzenie – w końcu marka słynie z tego, że od ponad 40 lat co roku wydaje kalendarz, na którego stronach zaprezentowane są nagie lub pół-nagie modelki, sfotografowane przez najlepszych artystów na świecie. Dlaczego więc w tym roku...

Brief.pl / Aktualności

Ruszył "Facebook" dla przedsiębiorców i naukowców 04/12/2015

Wystartowało Inventorum – portal społecznościowy dla przedsiębiorców i naukowców, który działa analogicznie do Facebooka. Misją serwisu jest pomoc naukowcom w komercjalizacji wyników badań i zwiększenie konkurencyjności polskich firm.

Brief.pl / Aktualności

13 polskich spółek w rankingu Deloitt...
03/12/2015
13 polskich spółek w rankingu Deloitte Technology Fast 500 EMEA

W tegorocznej, 15. edycji konkursu Deloitte Technology Fast 500 EMEA, grupującego najszybciej rozwijające się spółki technologiczne z regionu EMEA czyli Europa, Bliskich Wschód i Afryka, znalazło się 57 firm z Europy Środkowej, w tym 13 z Polski. Średni wzrost przychodów wszystkich laureatów wyniósł 1.012 proc. Najszybciej rozwijającym się przedsiębiorstwem technologicznym została holenderska firma Catawiki. Spośród polskich spółek najwyżej w rankingu uplasowała się firma Sky Cash Poland, która zajęła 46. miejsce.

Brief.pl / Wiedza

Repozycjonowanie. Kiedy zmienić wizer...
Repozycjonowanie. Kiedy zmienić wizerunek marki?

Wizerunek marki nie jest czymś stałym. Czasem nie oddaje do końca tego, jaka marka jest naprawdę. Przestaje być aktualny lub atrakcyjny i wymaga zmian. Repozycjonowanie może być procesem, który na nowo określi ramy funkcjonowania marki i stworzy koncept marketingowy. I co najważniejsze przyciągnie nowych odbiorców.

Brief.pl / Aktualności

Realny hejt
02/12/2015
Realny hejt

Głośno w ostatnich dniach o przypadku pewnego Brytyjczyka hinduskiego pochodzenia, który za turban i kolor skóry został pobity przed jednym z krakowskich klubów. Uderza jeszcze bardziej fakt, że turysta, przyjechał do Polski po to aby odwiedzić Auschwitz i oddać hołd pomordowanym tam więźniom. W obronie poszkodowanego stanęło wielu przechodniów, którzy prosili go, aby nie kojarzył Polków wyłącznie z agresywnym postawami. Takie przypadki należy piętnować, jednak czy jesteśmy tak samo zbulwersowani, gdy negatywne gesty i słowa padają w internecie?

Brief.pl / Technologie

Filmy 360 - narzędzie nowoczesnego ma...
Filmy 360 - narzędzie nowoczesnego marketera (case study)

W jaki sposób firmy korzystają z możliwości, jakie dają filmy 360 oraz wirtualna rzeczywistość? Przedstawiamy najciekawsze przykłady zastosowania wspomnianych technologii w działaniach marketingowych.

Brief.pl / Wiedza

E-marketing w muzyce
E-marketing w muzyce

Jak skutecznie promować muzykę w Internecie, aby trafić w oczekiwania polskich fanów muzyki? Oto kilka podstawowych wskazówek.

Brief.pl / Wiedza

Bezpieczna i skuteczna utylizacja dan...
Bezpieczna i skuteczna utylizacja danych bez tajemnic (infografika)

Bezpieczeństwo informacji to wśród polskich przedsiębiorców i urzędników wciąż temat budzący grozę. Pomimo, że jedna z podstawowych norm bezpieczeństwa DIN66399 obowiązuję już od 2012 roku, to w tym zakresie nadal pozostaje wiele niewiadomych. Należy pamiętać, że ponad 90 proc. leaków zawiera dane osobowe i poufne informacje firmowe1. Ewentualny wyciek danych stanowi ogromne zagrożenie dla każdej organizacji. Jak prawidłowo utylizować dokumenty zawierające poufne dane? Jak je archiwizować? Kto powinien mieć do nich dostęp?

Brief.pl / Technologie

Filmy 360 - narzędzie nowoczesnego ma...
Filmy 360 - narzędzie nowoczesnego marketera

Na rynku pojawiły się narzędzia do tworzenia filmów 360 oraz wirtualnej rzeczywistości. Czym się charakteryzują, jakie są ich zalety i jak marki mogą z nich korzystać? Zapraszamy do lektury.

Brief.pl / Wiedza

4 zasady motywacji pracowników
4 zasady motywacji pracowników

Pracownik dobry, kreatywny i chętnie realizujący postawione przed nim zadania to skarb. Nic więc dziwnego, że działy HR różnych firm traktują kwestię motywacji, zatrudnionych w organizacji osób, priorytetowo. Wiedzą oni, że poziom motywacji jest silnie połączony z jakością wykonywanej pracy. Niestety, odpowiedź na pytanie o to, co zrobić, by nasi pracownicy chętniej wykonywali swoje obowiązki oraz wychodzili z inicjatywą nie jest ani prosta, ani jednoznaczna.

Brief.pl / Wiedza

7 grzechów głównych prezentacji
7 grzechów głównych prezentacji

Historia premier nowych produktów Apple dowodzi, że dobry produkt wymaga jeszcze lepszej prezentacji. Tymczasem nasza codzienność wypełniona jest prezentacjami, podczas których częściej się ziewa niż nagradza brawami. Oto lista najpowszechniejszych błędów popełnianych podczas tworzenia prezentacji.

Brief.pl / Wiedza

Narzędzia Google – Pierwsze kroki z A...
Narzędzia Google – Pierwsze kroki z AdWords (cz. I)

Google w swojej ofercie ma wiele narzędzi, które ułatwiają na przykład pozycjonowanie swoich treści bądź dotarcie z produktem do wybranej grupy odbiorców. Przedstawiamy cykl poradnikowy, dzięki któremu dowiecie się jakich narzędzi od Google'a potrzebujecie oraz w jaki sposób z nich poprawnie korzystać. Rozpoczynamy od AdWords. Odpowiadamy na pytania do czego służy, jak działa oraz jak zacząć z niego korzystać.

Brief TV / Inspiracje

Barbara Piasek: Polskie startupy są w...
Barbara Piasek: Polskie startupy są wytrwałe

Czego brakuje polskim startupom? Dlaczego młodzi przedsiębiorcy powinni uczestniczyć w konferencjach? O czym należy pamiętać chcąc zrobić skuteczną i interesującą prezentację naszej firmy? Czego oczekują inwestorzy? I wreszcie, jakie są wyzwania związane z organizacją takiej konferencji, jaką jest Wolves Summit? Na te i inne pytania dotyczące polskiego rynku startupów odpowiada Barbara Piasek, jedna z organizatorek konferencji Wolves Summit.

Brief.pl / Wiedza

Okiem eksperta: Kilka słów o brand jo...
Okiem eksperta: Kilka słów o brand journalism

Na początek kontrowersyjna teza: czy w ogóle istnieje coś takiego, jak brand journalism? Do postawienia tego pytania skłonił mnie tekst znaleziony na blogu PressThink.org, który prowadzi Jay Rosen, profesor wykładający na nowojorskim uniwersytecie: „Content marketing z wartościową informacją kierowany jest do klientów – obecnych i potencjalnych. Dziennikarstwo adresowane jest do szerokiej publiczności”.

Narzędzia Google – Pierwsze kroki z AdWords (cz. I)
Przegląd kampanii świątecznych
4 zasady motywacji pracowników
Brand Journalism - poznaj program szkolenia
Finał konkursu „PRaktykuj za granicą” – staż na start z IMM!
NAGRODY „RESPONSIBLE BUSINESS AWARDS” ROZDANE!
Posłuchajmy mądrych kobiet – rusza II edycja Tygodnia Znanych Ekspertek
Czy wiesz, jak nauczać skutecznie? W Gdańsku odbyła się konferencja edukacyjna BeZee
Budujący spór o przyszłość
Brand Journalism - poznaj program szkolenia
Storytelling - program szkolenia
Analityka w content marketingu - program szkolenia
LABlife i Małgorzata Marczewska Zapraszają na THINKING DESIGN Roczny Kurs Projektowania Myślenia
Przeżyjmy to jeszcze raz! Gala 15 kreatywnych w nauce

/ Newsletter

e-mail:
imię:
nazwisko:
firma:
Wyrażam zgodę na przetwarzanie moich danych osobowych w celach marketingowych przez AdPress WR Sp. z o.o. z siedzibą w Warszawie przy ul. Zdrojowej 109, w szczególności na otrzymywanie informacji handlowych pochodzących od AdPress WR Sp. z o.o. oraz jego kontrahentów drogą elektroniczną na adres e-mail podany w formularzu zgłoszeniowym. Zapisz się